<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="模板名称:" prop="templateName" >
              <el-input v-model="state.form.templateName" placeholder="请输入模板名称"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <div style="display: flex;align-items: center;justify-content: space-between">
          <el-form-item label="创建部门:"  >
            <span style="font-size: 16px">{{state.deptName}}</span>
          </el-form-item>
          <el-form-item label="签署类型:"  prop="typeId">
            <el-select
                v-model="state.form.typeId"
                placeholder="请选择"
                style="width: 100%"
            >
              <el-option
                  v-for="item in state.typeList"
                  :key="item.id"
                  :label="item.typeName"
                  :value="item.id"
              />
            </el-select>
          </el-form-item>
        </div>

        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="签名文件附件:" prop="fileList" >
              <el-upload
                  v-model:file-list="state.form.fileList"
                  :action="uploadFileUrl"
                  :headers="state.header"
                  :on-remove="handleRemove"
                  :on-success="handleAvatarSuccess"
                  :on-change="handleChange"
                  accept=".pdf,.word"
                  :limit="state.limit"
                  style="width: 230px"
              >
                <el-button type="primary" plain> 点击上传 </el-button>
                <template #tip>
                  <div class="el-upload__tip">只能上传pdf类型，最多上传1份。</div>
                </template>
              </el-upload>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="签署效果预览:" style="display: flex;flex-direction: column;align-items: flex-start;width: 100%">
          <div style="width: 100%;height: auto;margin-left: 50px">
            <iframe
                v-if="state.iframeSrc"
                :src="state.iframeSrc"
                width="100%"
                height="750px"
                class="custom-iframe"
            ></iframe>
            <el-empty v-else></el-empty>
          </div>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";

const uploadFileUrl = ref(import.meta.env.VITE_APP_BASE_API + "/common/upload"); // 上传文件服务器地址
const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);

const state = reactive({
  form: {
    id: '',
    templateName: '',
    typeId:null,
    deptId: null,
    filePath: '',
    fileList: []
  },
  header: {
    Authorization: getToken()
  },
  iframeSrc: '',
  deptName: '',
  typeList: [],
  limit: 1,
  formRules:{
    templateName: [{ required: true, trigger: "blur", message:'请输入模板名称' }],
    typeId: [{ required: true, trigger: "blur", message:'请选择签署类型' }],
    fileList: [{ required: true, trigger: "blur", message:'请上传签名文件' }],
  },
})


const openDialog = async (type,value) => {
  await getSignTypeList()
  await getUserInfo()
  title.value = type === 'add' ? '新增' : '编辑'
  if(type === 'edit') {
    state.form = JSON.parse(JSON.stringify(value))
    if(state.form.filePath && state.form.fileName){
      const obj = {
        name: state.form.fileName,
        url : import.meta.env.VITE_APP_BASE_API + state.form.filePath
      }
      state.form.fileList = [obj]
      state.iframeSrc = import.meta.env.VITE_APP_BASE_API + state.form.filePath
    }else {
      state.form.fileList = []
    }

  }
  dialogVisible.value = true;
}

const getSignTypeList = async () => {
  const res = await getSignType()
  if(res.code == 200){
    state.typeList = res.data
  }else{
    ElMessage.warning(res.message)
  }
}
const getUserInfo = async () => {
  const res = await getInfo()
  if(res.code == 200){
    state.deptName = res.user.dept.deptName
    state.form.deptId = res.user.deptId
  }else{
    ElMessage.warning(res.message)
  }
}
const onSubmit = async () => {
  console.log('form',state.form)
  const valid = await busRef.value.validate();

  if(valid){
    if(title.value === '新增'){
      const {id,fileList, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addTemplate(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editTemplate(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }

  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    templateName: '',
    typeId:null,
    deptId: null,
    filePath: '',
    fileList: [],

  }
  state.iframeSrc = ''
}

const handleRemove = (file) => {
  const index = state.form.fileList.indexOf(file)
  const newFileList = state.form.fileList.slice()
  newFileList.splice(index, 1)
  state.form.fileList = newFileList;
  state.iframeSrc = ''
}
const f = ref()
const handleChange = (file,fileList) => {
  let fileExtension = file.name.split('.').pop();
  if(fileExtension == 'pdf' || fileExtension == 'word'){
    f.value = file.raw
  }else {
    state.form.fileList = []
    ElMessage.warning('仅可上传pdf或word文件')
  }
}
const handleAvatarSuccess = (res) => {
  if(res.code === 200){
    // ElMessage({
    //   type: 'success',
    //   message: '文件上传成功'
    // })
    state.form.filePath = res.fileName
    state.iframeSrc = import.meta.env.VITE_APP_BASE_API + state.form.filePath
  }else {
    state.form.fileList = []
    ElMessage({
      type: 'warning',
      message: res.message
    })
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
